<?php
/**
 * Custom functions needed by the plugin.
 * 
 * @package    Theme_Junkie_Testimonials_Content
 * @since      0.1.0
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2014, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 */

/**
 * Sets up the default arguments.
 * 
 * @since  0.1.0
 * @access public
 * @return array
 */
function tjtsc_get_default_args() {

	$defaults = array(
		'title'           => esc_attr__( 'Testimonials', 'tjtsc' ),
		'title_url'       => '',
		'limit'           => 1,
		'column'          => 1,
		'css_class'       => '',
		'before'          => '',
		'after'           => ''
	);

	/* Allow plugins/themes developer to filter the default arguments. */
	return apply_filters( 'tjtsc_default_args', $defaults );

}

/**
 * Outputs the testimonials.
 * 
 * @since  0.1.0
 * @access public
 * @param  array  $args
 */
function tjtsc_testimonials( $args = array() ) {
	echo tjtsc_get_testimonials( $args );
}

/**
 * Generates the related posts.
 *
 * @since  0.1.0
 * @access public
 * @param  array  $args
 * @return string|array The HTML for the related posts.
 */
function tjtsc_get_testimonials( $args = array() ) {
	global $post;

	/* Set up a default, empty $html variable. */
	$html = '';

	/* Get the default arguments. */
	$defaults = tjtsc_get_default_args();

	/* Merge the input arguments and the defaults. */
	$args = wp_parse_args( $args, $defaults );

	/* Extract the array to allow easy use of variables. */
	extract( $args );

	/* Allow devs to hook in stuff before the loop. */
	do_action( 'tjtsc_before_loop' );
	
	/* Get the posts query. */
	$posts = tjtsc_get_posts( $args );
	
	if ( $posts ) {

		$html = '<div id="tjtsc-testimonial" class="tjtsc-testimonial testimonial-column-' . sanitize_html_class( $args['column'] ) . ' ' . sanitize_html_class( $args['css_class'] ) . '">';

			$html .= '<ul>';

				foreach( $posts as $post ) {
					setup_postdata( $post );

					/* Get the meta boxes value. */
					$name     = get_post_meta( $post->ID, 'tj_testimonial_author_name', true );
					$avatar   = get_post_meta( $post->ID, 'tj_testimonial_author_avatar', true );
					$sitename = get_post_meta( $post->ID, 'tj_testimonial_site_name', true );
					$siteurl  = get_post_meta( $post->ID, 'tj_testimonial_site_url', true );

					/* Generate the related posts markup. */
					$html .= '<li>';
						$html .= '<p>' . get_the_content() . '</p>';
						if ( $avatar ) {
							$html .= '<img src="' . esc_url( $avatar ) . '" alt="' . esc_attr( $name ) . '" />';
						}
						$html .= '<cite>' . esc_attr( $name ) . ', <a href="' . esc_url( $sitename ) . '">' . esc_attr( $sitename ) . '</a></cite>';
					$html .= '</li>';

				}
			
			$html.= '</ul>';

		$html .= '</div><!-- Generated by Theme Junkie Testimonials Content plugin -->';

	}

	/* Restore original Post Data. */
	wp_reset_postdata();

	/* Allow devs to hook in stuff after the loop. */
	do_action( 'tjtsc_after_loop' );
	
	/* Return the related posts markup. */
	return $args['before'] . $html . $args['after'];

}

/**
 * The posts query.
 *
 * @since  0.1
 * @access public
 * @param  array  $args
 * @return array
 */
function tjtsc_get_posts( $args = array() ) {
	global $post;

	/* Query arguments. */
	$query = array(
		'posts_per_page' => $args['limit'],
		'post_type'      => 'testimonial'
	);

	/* Allow plugins/themes developer to filter the default query. */
	$query = apply_filters( 'tjtsc_query', $query );

	/* Perform the query. */
	$posts = get_posts( $query );
	
	return $posts;

}